@@ -39,7 +39,7 @@ TemplateSchema = Unischema('TemplateSchema', [
 ])
 
 
-MasSchema = Unischema('MasSchema', [
+MasDetSchema = Unischema('MasDetSchema', [
     UnischemaField('cam', np.string_, (), ScalarCodec(StringType()), False),
     UnischemaField('width', np.int_, (), ScalarCodec(IntegerType()), False),
     UnischemaField('height', np.int_, (), ScalarCodec(IntegerType()), False),
